RequestAttrs

Struct RequestAttrs 

pub struct RequestAttrs<'a> {
    pub tenant: Option<&'a PartitionId>,
    pub index: &'a str,
    pub principal: &'a PrincipalId,
    pub endpoint: EndpointKind,
}
The attributes of a request, evaluated against directive matches. The tenant is optional because it is only known after partition resolution.

Fields

tenant: Option<&'a PartitionId>

The resolved partition, if resolution has happened.

index: &'a str

The logical index from the request path.

principal: &'a PrincipalId

The authenticated principal.

endpoint: EndpointKind

The endpoint classification.